"""Common test classes and functions used by unit tests"""
import os


class TestHookenv(object):
    """
    Testing object to intercept juju calls and inject data, or make sure
    certain data is set.
    """

    _log = ()
    _incoming_relation_data = ()
    _outgoing_relation_data = ()
    _relation_list = ()
    _config = ()

    DEBUG = 0
    INFO = 1
    WARNING = 2
    ERROR = 3
    CRITICAL = 4

    def __init__(self, config={}):
        for key, value in config.iteritems():
            self._config = self._config + ((key, value),)

    def config(self, scope=None):
        """Return our initialized config information or a specific value"""
        if scope:
            for key, value in self._config:
                if key == scope:
                    return value
            return None
        return dict((key, value) for key, value in self._config)

    def relation_set(self, relid=None, relation_settings={}):
        """
        Capture result of relation_set into _outgoing_relation_data, which
        can then be checked later.
        """
        for key, value in relation_settings.iteritems():
            self._outgoing_relation_data = (
                self._outgoing_relation_data + ((key, value),))

    def relation_ids(self, relation_name="website"):
        """
        Hardcode expected relation_ids for tests.  Feel free to expand
        as more tests are added.
        """
        return ["%s:1" % relation_name]

    def related_units(self, relation_id="website:1"):
        """
        Hardcode expected related_units for tests.  Feel free to expand
        as more tests are added.
        """
        return ["%s/0" % relation_id.split(":")[0]]

    def relation_list(self):
        """
        Hardcode expected relation_list for tests.  Feel free to expand
        as more tests are added.
        """
        return list(self._relation_list)

    def unit_get(self, *args):
        """
        for now the only thing this is called for is "public-address",
        so it's a simplistic return.
        """
        return "localhost"

    def local_unit(self):
        return os.environ["JUJU_UNIT_NAME"]

    def charm_dir(self):
        return os.environ["CHARM_DIR"]

    def log(self, message, level):
        self._log = self._log + (message,)

    def is_logged(self, message):
        for line in self._log:
            if message in line:
                return True
        return False

    def config_get(self, scope=None):
        if scope:
            for key, value in self._config:
                if key == scope:
                    return scope
            return None
        return dict((key, value) for key, value in self._config)

    def relation_get(self, scope=None, unit=None, rid=None):
        data = self._incoming_relation_data
        if scope:
            for (rel_id, key, value) in data:
                if rel_id == rid and key == scope:
                    return value
            return None
        return dict(
            (key, value) for (rel_id, key, value) in data if rel_id == rid)
